{ config, lib, pkgs, modulesPath, ... }:

{
  boot = {
    kernelModules = [ "kvm-intel" ];
    initrd = {
      availableKernelModules = [
        "xhci_pci"
        "nvme"
        "usbhid"
        "usb_storage"
        "sd_mod"
      ];
      kernelModules = [ "dm-snapshot" ];
    };
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/db67d9e8-2ead-4fe6-8a63-5c9e5071e06e";
      fsType = "btrfs";
      options = [ "subvol=@" ];
    };
    "/home" = {
      device = "/dev/disk/by-uuid/db67d9e8-2ead-4fe6-8a63-5c9e5071e06e";
      fsType = "btrfs";
      options = [ "subvol=@home" ];
    };
    "/nix" = {
      device = "/dev/disk/by-uuid/db67d9e8-2ead-4fe6-8a63-5c9e5071e06e";
      fsType = "btrfs";
      options = [ "subvol=@nix" ];
    };
    "/var" = {
      device = "/dev/disk/by-uuid/db67d9e8-2ead-4fe6-8a63-5c9e5071e06e";
      fsType = "btrfs";
      options = [ "subvol=@var" ];
    };
    "/snapshots" = {
      device = "/dev/disk/by-uuid/db67d9e8-2ead-4fe6-8a63-5c9e5071e06e";
      fsType = "btrfs";
      options = [ "subvol=@snapshots" ];
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/7B59-F17A";
      fsType = "vfat";
      options = [ "fmask=0022" "dmask=0022" ];
    };

    # Remote
    "/home/jimbo/JimboNFS" = {
      device = "${config.ips.wgSpan}.1:/export/JimboNFS";
      fsType = "nfs4";
      options = [ "x-systemd.automount" "_netdev" "nofail" "noauto" ];
    };
  };

  swapDevices = [
    { device = "/dev/disk/by-uuid/25b5e281-f1be-49ca-991e-b340fed3e5da"; }
  ];

  networking.useDHCP = lib.mkDefault true;
  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.intel.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
